@@ -1,5 +1,5 @@
 import pytest
-from mitmproxy.http import HTTPFlow, HTTPResponse
+from mitmproxy.http import HTTPFlow, Response
 from mitmproxy.test import taddons, tflow
 from xepor import InterceptedAPI
 
@@ -15,20 +15,33 @@ def api_simple():
 
     @api.route("/test")
     def route1(flow: HTTPFlow):
-        flow.response = HTTPResponse.make(200, "TEST intercepted")
+        flow.response = Response.make(200, "TEST intercepted")
+
+    @api.route(
+        "/{}/{}/{vid}_1.m3u8",
+        "hls.videocc.net",
+    )
+    def route2(flow: HTTPFlow, *args, vid):
+        flow.response = Response.make(200, "TEST 2 INTERCEPTED")
 
     return api
 
 
-def test_intercepted_route(api_simple):
+@pytest.mark.parametrize(
+    "req_url,resp_body",
+    [
+        ("http://example.com/test", "TEST intercepted"),
+        ("http://hls.videocc.net/jkag324wd2/e/cwqzcxkvj0iukomqxu0l591u2dke4vkc_1.m3u8", "TEST 2 INTERCEPTED"),
+    ],
+)
+def test_intercepted_route(api_simple, req_url, resp_body):
     with taddons.context(api_simple) as tctx:
         flow = tflow.tflow()
-        flow.request.host = "example.com"
-        flow.request.path = "/test"
+        flow.request.url = req_url
         assert flow.response is None
 
         api_simple.request(flow)
-        assert "TEST intercepted" in flow.response.text
+        assert resp_body in flow.response.text
 
 
 def test_non_intercepted_route(api_simple):
